@@ -20,9 +20,17 @@
  *
  */
 
-
 package weka.experiment;
 
+import java.io.ByteArrayOutputStream;
+import java.io.ObjectOutputStream;
+import java.io.ObjectStreamClass;
+import java.io.Serializable;
+import java.lang.management.ManagementFactory;
+import java.lang.management.ThreadMXBean;
+import java.util.Enumeration;
+import java.util.Vector;
+
 import weka.classifiers.Classifier;
 import weka.classifiers.Evaluation;
 import weka.classifiers.rules.ZeroR;
@@ -37,45 +45,39 @@ import weka.core.RevisionUtils;
 import weka.core.Summarizable;
 import weka.core.Utils;
 
-import java.io.ByteArrayOutputStream;
-import java.io.ObjectOutputStream;
-import java.io.ObjectStreamClass;
-import java.io.Serializable;
-import java.lang.management.ManagementFactory;
-import java.lang.management.ThreadMXBean;
-import java.util.Enumeration;
-import java.util.Vector;
-
 /**
- <!-- globalinfo-start -->
- * A SplitEvaluator that produces results for a classification scheme on a numeric class attribute.
+ * <!-- globalinfo-start --> A SplitEvaluator that produces results for a
+ * classification scheme on a numeric class attribute.
  * <p/>
- <!-- globalinfo-end -->
- *
- <!-- options-start -->
- * Valid options are: <p/>
+ * <!-- globalinfo-end -->
  * 
- * <pre> -W &lt;class name&gt;
+ * <!-- options-start --> Valid options are:
+ * <p/>
+ * 
+ * <pre>
+ * -W &lt;class name&gt;
  *  The full class name of the classifier.
- *  eg: weka.classifiers.bayes.NaiveBayes</pre>
+ *  eg: weka.classifiers.bayes.NaiveBayes
+ * </pre>
  * 
- * <pre> 
+ * <pre>
  * Options specific to classifier weka.classifiers.rules.ZeroR:
  * </pre>
  * 
- * <pre> -D
+ * <pre>
+ * -D
  *  If set, classifier is run in debug mode and
- *  may output additional info to the console</pre>
+ *  may output additional info to the console
+ * </pre>
  * 
- <!-- options-end -->
+ * <!-- options-end -->
  * 
  * @author Len Trigg (trigg@cs.waikato.ac.nz)
- * @version $Revision: 7510 $
+ * @version $Revision: 10475 $
  */
-public class RegressionSplitEvaluator 
-  implements SplitEvaluator, OptionHandler, AdditionalMeasureProducer,
-             RevisionHandler {
-  
+public class RegressionSplitEvaluator implements SplitEvaluator, OptionHandler,
+  AdditionalMeasureProducer, RevisionHandler {
+
   /** for serialization */
   static final long serialVersionUID = -328181640503349202L;
 
@@ -84,14 +86,16 @@ public class RegressionSplitEvaluator
 
   /** The classifier used for evaluation */
   protected Classifier m_Classifier;
-  
-  /** The names of any additional measures to look for in SplitEvaluators */
-  protected String [] m_AdditionalMeasures = null;
 
-  /** Array of booleans corresponding to the measures in m_AdditionalMeasures
-      indicating which of the AdditionalMeasures the current classifier
-      can produce */
-  protected boolean [] m_doesProduce = null;
+  /** The names of any additional measures to look for in SplitEvaluators */
+  protected String[] m_AdditionalMeasures = null;
+
+  /**
+   * Array of booleans corresponding to the measures in m_AdditionalMeasures
+   * indicating which of the AdditionalMeasures the current classifier can
+   * produce
+   */
+  protected boolean[] m_doesProduce = null;
 
   /** Holds the statistics for the most recent application of the classifier */
   protected String m_result = null;
@@ -106,7 +110,7 @@ public class RegressionSplitEvaluator
   private static final int KEY_SIZE = 3;
 
   /** The length of a result */
-  private static final int RESULT_SIZE = 21;
+  private static final int RESULT_SIZE = 23;
 
   /**
    * No args constructor.
@@ -118,100 +122,104 @@ public class RegressionSplitEvaluator
 
   /**
    * Returns a string describing this split evaluator
-   * @return a description of the split evaluator suitable for
-   * displaying in the explorer/experimenter gui
+   * 
+   * @return a description of the split evaluator suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String globalInfo() {
     return "A SplitEvaluator that produces results for a classification "
-      +"scheme on a numeric class attribute.";
+      + "scheme on a numeric class attribute.";
   }
 
   /**
    * Returns an enumeration describing the available options..
-   *
+   * 
    * @return an enumeration of all the available options.
    */
+  @Override
   public Enumeration listOptions() {
 
     Vector newVector = new Vector(1);
 
-    newVector.addElement(new Option(
-	     "\tThe full class name of the classifier.\n"
-	      +"\teg: weka.classifiers.bayes.NaiveBayes", 
-	     "W", 1, 
-	     "-W <class name>"));
+    newVector
+      .addElement(new Option("\tThe full class name of the classifier.\n"
+        + "\teg: weka.classifiers.bayes.NaiveBayes", "W", 1, "-W <class name>"));
 
-    if ((m_Template != null) &&
-	(m_Template instanceof OptionHandler)) {
-      newVector.addElement(new Option(
-	     "",
-	     "", 0, "\nOptions specific to classifier "
-	     + m_Template.getClass().getName() + ":"));
-      Enumeration enu = ((OptionHandler)m_Template).listOptions();
+    if ((m_Template != null) && (m_Template instanceof OptionHandler)) {
+      newVector.addElement(new Option("", "", 0,
+        "\nOptions specific to classifier " + m_Template.getClass().getName()
+          + ":"));
+      Enumeration enu = ((OptionHandler) m_Template).listOptions();
       while (enu.hasMoreElements()) {
-	newVector.addElement(enu.nextElement());
+        newVector.addElement(enu.nextElement());
       }
     }
     return newVector.elements();
   }
 
   /**
-   * Parses a given list of options. <p/>
-   *
-   <!-- options-start -->
-   * Valid options are: <p/>
+   * Parses a given list of options.
+   * <p/>
    * 
-   * <pre> -W &lt;class name&gt;
+   * <!-- options-start --> Valid options are:
+   * <p/>
+   * 
+   * <pre>
+   * -W &lt;class name&gt;
    *  The full class name of the classifier.
-   *  eg: weka.classifiers.bayes.NaiveBayes</pre>
+   *  eg: weka.classifiers.bayes.NaiveBayes
+   * </pre>
    * 
-   * <pre> 
+   * <pre>
    * Options specific to classifier weka.classifiers.rules.ZeroR:
    * </pre>
    * 
-   * <pre> -D
+   * <pre>
+   * -D
    *  If set, classifier is run in debug mode and
-   *  may output additional info to the console</pre>
+   *  may output additional info to the console
+   * </pre>
+   * 
+   * <!-- options-end -->
    * 
-   <!-- options-end -->
-   *
    * All option after -- will be passed to the classifier.
-   *
+   * 
    * @param options the list of options as an array of strings
    * @throws Exception if an option is not supported
    */
+  @Override
   public void setOptions(String[] options) throws Exception {
-    
+
     String cName = Utils.getOption('W', options);
     if (cName.length() == 0) {
       throw new Exception("A classifier must be specified with"
-			  + " the -W option.");
+        + " the -W option.");
     }
     // Do it first without options, so if an exception is thrown during
     // the option setting, listOptions will contain options for the actual
     // Classifier.
     setClassifier(Classifier.forName(cName, null));
     if (getClassifier() instanceof OptionHandler) {
-      ((OptionHandler) getClassifier())
-	.setOptions(Utils.partitionOptions(options));
+      ((OptionHandler) getClassifier()).setOptions(Utils
+        .partitionOptions(options));
       updateOptions();
     }
   }
 
   /**
    * Gets the current settings of the Classifier.
-   *
+   * 
    * @return an array of strings suitable for passing to setOptions
    */
-  public String [] getOptions() {
+  @Override
+  public String[] getOptions() {
 
-    String [] classifierOptions = new String [0];
-    if ((m_Template != null) && 
-	(m_Template instanceof OptionHandler)) {
-      classifierOptions = ((OptionHandler)m_Template).getOptions();
+    String[] classifierOptions = new String[0];
+    if ((m_Template != null) && (m_Template instanceof OptionHandler)) {
+      classifierOptions = ((OptionHandler) m_Template).getOptions();
     }
-    
-    String [] options = new String [classifierOptions.length + 3];
+
+    String[] options = new String[classifierOptions.length + 3];
     int current = 0;
 
     if (getClassifier() != null) {
@@ -220,8 +228,8 @@ public class RegressionSplitEvaluator
     }
     options[current++] = "--";
 
-    System.arraycopy(classifierOptions, 0, options, current, 
-		     classifierOptions.length);
+    System.arraycopy(classifierOptions, 0, options, current,
+      classifierOptions.length);
     current += classifierOptions.length;
     while (current < options.length) {
       options[current++] = "";
@@ -230,90 +238,95 @@ public class RegressionSplitEvaluator
   }
 
   /**
-   * Set a list of method names for additional measures to look for
-   * in Classifiers. This could contain many measures (of which only a
-   * subset may be produceable by the current Classifier) if an experiment
-   * is the type that iterates over a set of properties.
+   * Set a list of method names for additional measures to look for in
+   * Classifiers. This could contain many measures (of which only a subset may
+   * be produceable by the current Classifier) if an experiment is the type that
+   * iterates over a set of properties.
+   * 
    * @param additionalMeasures an array of method names.
    */
-  public void setAdditionalMeasures(String [] additionalMeasures) {
+  @Override
+  public void setAdditionalMeasures(String[] additionalMeasures) {
     m_AdditionalMeasures = additionalMeasures;
 
     // determine which (if any) of the additional measures this classifier
     // can produce
     if (m_AdditionalMeasures != null && m_AdditionalMeasures.length > 0) {
-      m_doesProduce = new boolean [m_AdditionalMeasures.length];
+      m_doesProduce = new boolean[m_AdditionalMeasures.length];
 
       if (m_Template instanceof AdditionalMeasureProducer) {
-	Enumeration en = ((AdditionalMeasureProducer)m_Template).
-	  enumerateMeasures();
-	while (en.hasMoreElements()) {
-	  String mname = (String)en.nextElement();
-	  for (int j=0;j<m_AdditionalMeasures.length;j++) {
-	    if (mname.compareToIgnoreCase(m_AdditionalMeasures[j]) == 0) {
-	      m_doesProduce[j] = true;
-	    }
-	  }
-	}
+        Enumeration en = ((AdditionalMeasureProducer) m_Template)
+          .enumerateMeasures();
+        while (en.hasMoreElements()) {
+          String mname = (String) en.nextElement();
+          for (int j = 0; j < m_AdditionalMeasures.length; j++) {
+            if (mname.compareToIgnoreCase(m_AdditionalMeasures[j]) == 0) {
+              m_doesProduce[j] = true;
+            }
+          }
+        }
       }
     } else {
       m_doesProduce = null;
     }
   }
-  
 
-    /**
-   * Returns an enumeration of any additional measure names that might be
-   * in the classifier
+  /**
+   * Returns an enumeration of any additional measure names that might be in the
+   * classifier
+   * 
    * @return an enumeration of the measure names
    */
+  @Override
   public Enumeration enumerateMeasures() {
     Vector newVector = new Vector();
     if (m_Template instanceof AdditionalMeasureProducer) {
-      Enumeration en = ((AdditionalMeasureProducer)m_Template).
-	enumerateMeasures();
+      Enumeration en = ((AdditionalMeasureProducer) m_Template)
+        .enumerateMeasures();
       while (en.hasMoreElements()) {
-	String mname = (String)en.nextElement();
-	newVector.addElement(mname);
+        String mname = (String) en.nextElement();
+        newVector.addElement(mname);
       }
     }
     return newVector.elements();
   }
-  
+
   /**
    * Returns the value of the named measure
+   * 
    * @param additionalMeasureName the name of the measure to query for its value
    * @return the value of the named measure
    * @throws IllegalArgumentException if the named measure is not supported
    */
+  @Override
   public double getMeasure(String additionalMeasureName) {
     if (m_Template instanceof AdditionalMeasureProducer) {
       if (m_Classifier == null) {
-	throw new IllegalArgumentException("ClassifierSplitEvaluator: " +
-					   "Can't return result for measure, " +
-					   "classifier has not been built yet.");
+        throw new IllegalArgumentException("ClassifierSplitEvaluator: "
+          + "Can't return result for measure, "
+          + "classifier has not been built yet.");
       }
-      return ((AdditionalMeasureProducer)m_Classifier).
-	getMeasure(additionalMeasureName);
+      return ((AdditionalMeasureProducer) m_Classifier)
+        .getMeasure(additionalMeasureName);
     } else {
       throw new IllegalArgumentException("ClassifierSplitEvaluator: "
-			  +"Can't return value for : "+additionalMeasureName
-			  +". "+m_Template.getClass().getName()+" "
-			  +"is not an AdditionalMeasureProducer");
+        + "Can't return value for : " + additionalMeasureName + ". "
+        + m_Template.getClass().getName() + " "
+        + "is not an AdditionalMeasureProducer");
     }
   }
 
   /**
    * Gets the data types of each of the key columns produced for a single run.
-   * The number of key fields must be constant
-   * for a given SplitEvaluator.
-   *
-   * @return an array containing objects of the type of each key column. The 
-   * objects should be Strings, or Doubles.
+   * The number of key fields must be constant for a given SplitEvaluator.
+   * 
+   * @return an array containing objects of the type of each key column. The
+   *         objects should be Strings, or Doubles.
    */
-  public Object [] getKeyTypes() {
+  @Override
+  public Object[] getKeyTypes() {
 
-    Object [] keyTypes = new Object[KEY_SIZE];
+    Object[] keyTypes = new Object[KEY_SIZE];
     keyTypes[0] = "";
     keyTypes[1] = "";
     keyTypes[2] = "";
@@ -321,15 +334,15 @@ public class RegressionSplitEvaluator
   }
 
   /**
-   * Gets the names of each of the key columns produced for a single run.
-   * The number of key fields must be constant
-   * for a given SplitEvaluator.
-   *
+   * Gets the names of each of the key columns produced for a single run. The
+   * number of key fields must be constant for a given SplitEvaluator.
+   * 
    * @return an array containing the name of each key column
    */
-  public String [] getKeyNames() {
+  @Override
+  public String[] getKeyNames() {
 
-    String [] keyNames = new String[KEY_SIZE];
+    String[] keyNames = new String[KEY_SIZE];
     keyNames[0] = "Scheme";
     keyNames[1] = "Scheme_options";
     keyNames[2] = "Scheme_version_ID";
@@ -337,16 +350,17 @@ public class RegressionSplitEvaluator
   }
 
   /**
-   * Gets the key describing the current SplitEvaluator. For example
-   * This may contain the name of the classifier used for classifier
-   * predictive evaluation. The number of key fields must be constant
-   * for a given SplitEvaluator.
-   *
+   * Gets the key describing the current SplitEvaluator. For example This may
+   * contain the name of the classifier used for classifier predictive
+   * evaluation. The number of key fields must be constant for a given
+   * SplitEvaluator.
+   * 
    * @return an array of objects containing the key.
    */
-  public Object [] getKey(){
+  @Override
+  public Object[] getKey() {
 
-    Object [] key = new Object[KEY_SIZE];
+    Object[] key = new Object[KEY_SIZE];
     key[0] = m_Template.getClass().getName();
     key[1] = m_ClassifierOptions;
     key[2] = m_ClassifierVersion;
@@ -354,18 +368,17 @@ public class RegressionSplitEvaluator
   }
 
   /**
-   * Gets the data types of each of the result columns produced for a 
-   * single run. The number of result fields must be constant
-   * for a given SplitEvaluator.
-   *
-   * @return an array containing objects of the type of each result column. 
-   * The objects should be Strings, or Doubles.
+   * Gets the data types of each of the result columns produced for a single
+   * run. The number of result fields must be constant for a given
+   * SplitEvaluator.
+   * 
+   * @return an array containing objects of the type of each result column. The
+   *         objects should be Strings, or Doubles.
    */
-  public Object [] getResultTypes() {
-    int addm = (m_AdditionalMeasures != null) 
-      ? m_AdditionalMeasures.length 
-      : 0;
-    Object [] resultTypes = new Object[RESULT_SIZE+addm];
+  @Override
+  public Object[] getResultTypes() {
+    int addm = (m_AdditionalMeasures != null) ? m_AdditionalMeasures.length : 0;
+    Object[] resultTypes = new Object[RESULT_SIZE + addm];
     Double doub = new Double(0);
     int current = 0;
     resultTypes[current++] = doub;
@@ -376,6 +389,8 @@ public class RegressionSplitEvaluator
     resultTypes[current++] = doub;
     resultTypes[current++] = doub;
     resultTypes[current++] = doub;
+    resultTypes[current++] = doub;
+    resultTypes[current++] = doub;
 
     resultTypes[current++] = doub;
     resultTypes[current++] = doub;
@@ -389,7 +404,7 @@ public class RegressionSplitEvaluator
     resultTypes[current++] = doub;
     resultTypes[current++] = doub;
     resultTypes[current++] = doub;
-    
+
     // sizes
     resultTypes[current++] = doub;
     resultTypes[current++] = doub;
@@ -398,27 +413,25 @@ public class RegressionSplitEvaluator
     resultTypes[current++] = "";
 
     // add any additional measures
-    for (int i=0;i<addm;i++) {
+    for (int i = 0; i < addm; i++) {
       resultTypes[current++] = doub;
     }
-    if (current != RESULT_SIZE+addm) {
+    if (current != RESULT_SIZE + addm) {
       throw new Error("ResultTypes didn't fit RESULT_SIZE");
     }
     return resultTypes;
   }
 
   /**
-   * Gets the names of each of the result columns produced for a single run.
-   * The number of result fields must be constant
-   * for a given SplitEvaluator.
-   *
+   * Gets the names of each of the result columns produced for a single run. The
+   * number of result fields must be constant for a given SplitEvaluator.
+   * 
    * @return an array containing the name of each result column
    */
-  public String [] getResultNames() {
-    int addm = (m_AdditionalMeasures != null) 
-      ? m_AdditionalMeasures.length 
-      : 0;
-    String [] resultNames = new String[RESULT_SIZE+addm];
+  @Override
+  public String[] getResultNames() {
+    int addm = (m_AdditionalMeasures != null) ? m_AdditionalMeasures.length : 0;
+    String[] resultNames = new String[RESULT_SIZE + addm];
     int current = 0;
     resultNames[current++] = "Number_of_training_instances";
     resultNames[current++] = "Number_of_testing_instances";
@@ -429,6 +442,8 @@ public class RegressionSplitEvaluator
     resultNames[current++] = "Relative_absolute_error";
     resultNames[current++] = "Root_relative_squared_error";
     resultNames[current++] = "Correlation_coefficient";
+    resultNames[current++] = "Number_unclassified";
+    resultNames[current++] = "Percent_unclassified";
 
     // SF stats
     resultNames[current++] = "SF_prior_entropy";
@@ -448,32 +463,32 @@ public class RegressionSplitEvaluator
     resultNames[current++] = "Serialized_Model_Size";
     resultNames[current++] = "Serialized_Train_Set_Size";
     resultNames[current++] = "Serialized_Test_Set_Size";
-    
+
     // Classifier defined extras
     resultNames[current++] = "Summary";
     // add any additional measures
-    for (int i=0;i<addm;i++) {
+    for (int i = 0; i < addm; i++) {
       resultNames[current++] = m_AdditionalMeasures[i];
     }
-    if (current != RESULT_SIZE+addm) {
+    if (current != RESULT_SIZE + addm) {
       throw new Error("ResultNames didn't fit RESULT_SIZE");
     }
     return resultNames;
   }
 
   /**
-   * Gets the results for the supplied train and test datasets. Now performs
-   * a deep copy of the classifier before it is built and evaluated (just in case
+   * Gets the results for the supplied train and test datasets. Now performs a
+   * deep copy of the classifier before it is built and evaluated (just in case
    * the classifier is not initialized properly in buildClassifier()).
-   *
+   * 
    * @param train the training Instances.
    * @param test the testing Instances.
-   * @return the results stored in an array. The objects stored in
-   * the array may be Strings, Doubles, or null (for the missing value).
+   * @return the results stored in an array. The objects stored in the array may
+   *         be Strings, Doubles, or null (for the missing value).
    * @throws Exception if a problem occurs while getting the results
    */
-  public Object [] getResult(Instances train, Instances test) 
-    throws Exception {
+  @Override
+  public Object[] getResult(Instances train, Instances test) throws Exception {
 
     if (train.classAttribute().type() != Attribute.NUMERIC) {
       throw new Exception("Class attribute is not numeric!");
@@ -483,33 +498,37 @@ public class RegressionSplitEvaluator
     }
     ThreadMXBean thMonitor = ManagementFactory.getThreadMXBean();
     boolean canMeasureCPUTime = thMonitor.isThreadCpuTimeSupported();
-    if(canMeasureCPUTime && !thMonitor.isThreadCpuTimeEnabled())
+    if (canMeasureCPUTime && !thMonitor.isThreadCpuTimeEnabled()) {
       thMonitor.setThreadCpuTimeEnabled(true);
-    
+    }
+
     int addm = (m_AdditionalMeasures != null) ? m_AdditionalMeasures.length : 0;
-    Object [] result = new Object[RESULT_SIZE+addm];
+    Object[] result = new Object[RESULT_SIZE + addm];
     long thID = Thread.currentThread().getId();
-    long CPUStartTime=-1, trainCPUTimeElapsed=-1, testCPUTimeElapsed=-1,
-         trainTimeStart, trainTimeElapsed, testTimeStart, testTimeElapsed;    
+    long CPUStartTime = -1, trainCPUTimeElapsed = -1, testCPUTimeElapsed = -1, trainTimeStart, trainTimeElapsed, testTimeStart, testTimeElapsed;
     Evaluation eval = new Evaluation(train);
     m_Classifier = Classifier.makeCopy(m_Template);
 
     trainTimeStart = System.currentTimeMillis();
-    if(canMeasureCPUTime)
+    if (canMeasureCPUTime) {
       CPUStartTime = thMonitor.getThreadUserTime(thID);
+    }
     m_Classifier.buildClassifier(train);
-    if(canMeasureCPUTime)
+    if (canMeasureCPUTime) {
       trainCPUTimeElapsed = thMonitor.getThreadUserTime(thID) - CPUStartTime;
+    }
     trainTimeElapsed = System.currentTimeMillis() - trainTimeStart;
     testTimeStart = System.currentTimeMillis();
-    if(canMeasureCPUTime)
+    if (canMeasureCPUTime) {
       CPUStartTime = thMonitor.getThreadUserTime(thID);
+    }
     eval.evaluateModel(m_Classifier, test);
-    if(canMeasureCPUTime)
+    if (canMeasureCPUTime) {
       testCPUTimeElapsed = thMonitor.getThreadUserTime(thID) - CPUStartTime;
+    }
     testTimeElapsed = System.currentTimeMillis() - testTimeStart;
     thMonitor = null;
-    
+
     m_result = eval.toSummaryString();
     // The results stored are all per instance -- can be multiplied by the
     // number of instances to get absolute numbers
@@ -522,6 +541,8 @@ public class RegressionSplitEvaluator
     result[current++] = new Double(eval.relativeAbsoluteError());
     result[current++] = new Double(eval.rootRelativeSquaredError());
     result[current++] = new Double(eval.correlationCoefficient());
+    result[current++] = new Double(eval.unclassified());
+    result[current++] = new Double(eval.pctUnclassified());
 
     result[current++] = new Double(eval.SFPriorEntropy());
     result[current++] = new Double(eval.SFSchemeEntropy());
@@ -529,19 +550,18 @@ public class RegressionSplitEvaluator
     result[current++] = new Double(eval.SFMeanPriorEntropy());
     result[current++] = new Double(eval.SFMeanSchemeEntropy());
     result[current++] = new Double(eval.SFMeanEntropyGain());
-    
+
     // Timing stats
     result[current++] = new Double(trainTimeElapsed / 1000.0);
     result[current++] = new Double(testTimeElapsed / 1000.0);
-    if(canMeasureCPUTime) {
-      result[current++] = new Double((trainCPUTimeElapsed/1000000.0) / 1000.0);
-      result[current++] = new Double((testCPUTimeElapsed /1000000.0) / 1000.0);
-    }
-    else {
+    if (canMeasureCPUTime) {
+      result[current++] = new Double((trainCPUTimeElapsed / 1000000.0) / 1000.0);
+      result[current++] = new Double((testCPUTimeElapsed / 1000000.0) / 1000.0);
+    } else {
       result[current++] = new Double(Instance.missingValue());
       result[current++] = new Double(Instance.missingValue());
     }
-    
+
     // sizes
     ByteArrayOutputStream bastream = new ByteArrayOutputStream();
     ObjectOutputStream oostream = new ObjectOutputStream(bastream);
@@ -555,18 +575,18 @@ public class RegressionSplitEvaluator
     oostream = new ObjectOutputStream(bastream);
     oostream.writeObject(test);
     result[current++] = new Double(bastream.size());
-    
+
     if (m_Classifier instanceof Summarizable) {
-      result[current++] = ((Summarizable)m_Classifier).toSummaryString();
+      result[current++] = ((Summarizable) m_Classifier).toSummaryString();
     } else {
       result[current++] = null;
     }
-    
-    for (int i=0;i<addm;i++) {
+
+    for (int i = 0; i < addm; i++) {
       if (m_doesProduce[i]) {
         try {
-          double dv = ((AdditionalMeasureProducer)m_Classifier).
-          getMeasure(m_AdditionalMeasures[i]);
+          double dv = ((AdditionalMeasureProducer) m_Classifier)
+            .getMeasure(m_AdditionalMeasures[i]);
           if (!Instance.isMissingValue(dv)) {
             Double value = new Double(dv);
             result[current++] = value;
@@ -580,8 +600,8 @@ public class RegressionSplitEvaluator
         result[current++] = null;
       }
     }
-    
-    if (current != RESULT_SIZE+addm) {
+
+    if (current != RESULT_SIZE + addm) {
       throw new Error("Results didn't fit RESULT_SIZE");
     }
     return result;
@@ -589,8 +609,9 @@ public class RegressionSplitEvaluator
 
   /**
    * Returns the tip text for this property
-   * @return tip text for this property suitable for
-   * displaying in the explorer/experimenter gui
+   * 
+   * @return tip text for this property suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String classifierTipText() {
     return "The classifier to use.";
@@ -598,21 +619,21 @@ public class RegressionSplitEvaluator
 
   /**
    * Get the value of Classifier.
-   *
+   * 
    * @return Value of Classifier.
    */
   public Classifier getClassifier() {
-    
+
     return m_Template;
   }
-  
+
   /**
    * Sets the classifier.
-   *
+   * 
    * @param newClassifier the new classifier to use.
    */
   public void setClassifier(Classifier newClassifier) {
-    
+
     m_Template = newClassifier;
     updateOptions();
 
@@ -623,16 +644,15 @@ public class RegressionSplitEvaluator
    * Updates the options that the current classifier is using.
    */
   protected void updateOptions() {
-    
+
     if (m_Template instanceof OptionHandler) {
-      m_ClassifierOptions = Utils.joinOptions(((OptionHandler)m_Template)
-					      .getOptions());
+      m_ClassifierOptions = Utils.joinOptions(((OptionHandler) m_Template)
+        .getOptions());
     } else {
       m_ClassifierOptions = "";
     }
     if (m_Template instanceof Serializable) {
-      ObjectStreamClass obs = ObjectStreamClass.lookup(m_Template
-						       .getClass());
+      ObjectStreamClass obs = ObjectStreamClass.lookup(m_Template.getClass());
       m_ClassifierVersion = "" + obs.getSerialVersionUID();
     } else {
       m_ClassifierVersion = "";
@@ -642,25 +662,26 @@ public class RegressionSplitEvaluator
   /**
    * Set the Classifier to use, given it's class name. A new classifier will be
    * instantiated.
-   *
+   * 
    * @param newClassifierName the Classifier class name.
    * @throws Exception if the class name is invalid.
    */
   public void setClassifierName(String newClassifierName) throws Exception {
 
     try {
-      setClassifier((Classifier)Class.forName(newClassifierName)
-		    .newInstance());
+      setClassifier((Classifier) Class.forName(newClassifierName).newInstance());
     } catch (Exception ex) {
       throw new Exception("Can't find Classifier with class name: "
-			  + newClassifierName);
+        + newClassifierName);
     }
   }
 
   /**
    * Gets the raw output from the classifier
+   * 
    * @return the raw output from the classifier
    */
+  @Override
   public String getRawResultOutput() {
     StringBuffer result = new StringBuffer();
 
@@ -668,29 +689,29 @@ public class RegressionSplitEvaluator
       return "<null> classifier";
     }
     result.append(toString());
-    result.append("Classifier model: \n"+m_Classifier.toString()+'\n');
+    result.append("Classifier model: \n" + m_Classifier.toString() + '\n');
 
     // append the performance statistics
     if (m_result != null) {
       result.append(m_result);
-      
+
       if (m_doesProduce != null) {
-	for (int i=0;i<m_doesProduce.length;i++) {
-	  if (m_doesProduce[i]) {
-	    try {
-	      double dv = ((AdditionalMeasureProducer)m_Classifier).
-		getMeasure(m_AdditionalMeasures[i]);
-	      if (!Instance.isMissingValue(dv)) {
-		Double value = new Double(dv);
-		result.append(m_AdditionalMeasures[i]+" : "+value+'\n');
-	      } else {
-		result.append(m_AdditionalMeasures[i]+" : "+'?'+'\n');
-	      }
-	    } catch (Exception ex) {
-	      System.err.println(ex);
-	    }
-	  } 
-	}
+        for (int i = 0; i < m_doesProduce.length; i++) {
+          if (m_doesProduce[i]) {
+            try {
+              double dv = ((AdditionalMeasureProducer) m_Classifier)
+                .getMeasure(m_AdditionalMeasures[i]);
+              if (!Instance.isMissingValue(dv)) {
+                Double value = new Double(dv);
+                result.append(m_AdditionalMeasures[i] + " : " + value + '\n');
+              } else {
+                result.append(m_AdditionalMeasures[i] + " : " + '?' + '\n');
+              }
+            } catch (Exception ex) {
+              System.err.println(ex);
+            }
+          }
+        }
       }
     }
     return result.toString();
@@ -698,25 +719,27 @@ public class RegressionSplitEvaluator
 
   /**
    * Returns a text description of the split evaluator.
-   *
+   * 
    * @return a text description of the split evaluator.
    */
+  @Override
   public String toString() {
 
     String result = "RegressionSplitEvaluator: ";
     if (m_Template == null) {
       return result + "<null> classifier";
     }
-    return result + m_Template.getClass().getName() + " " 
-      + m_ClassifierOptions + "(version " + m_ClassifierVersion + ")";
+    return result + m_Template.getClass().getName() + " " + m_ClassifierOptions
+      + "(version " + m_ClassifierVersion + ")";
   }
-  
+
   /**
    * Returns the revision string.
    * 
-   * @return		the revision
+   * @return the revision
    */
+  @Override
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 7510 $");
+    return RevisionUtils.extract("$Revision: 10475 $");
   }
 } // RegressionSplitEvaluator
