@@ -103,7 +103,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author Ashraf M. Kibriya (amk14@cs.waikato.ac.nz) 
- * @version $Revision: 6750 $ [1.0 - 22 July 2003 - Initial version (Ashraf M. Kibriya)]
+ * @version $Revision: 10029 $ [1.0 - 22 July 2003 - Initial version (Ashraf M. Kibriya)]
  */
 public class RandomProjection 
   extends Filter 
@@ -765,7 +765,7 @@ public class RandomProjection
       }
       if(currentFormat.classIndex()!=-1)  {  //if classindex is set
 	  //attributes.removeElementAt(attributes.size()-1);
-	  attributes.addElement(currentFormat.attribute(currentFormat.classIndex()));
+	  attributes.addElement(currentFormat.attribute(currentFormat.classIndex()).copy());
 	  newClassIndex = attributes.size()-1;
       }
 
@@ -891,7 +891,7 @@ public class RandomProjection
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 6750 $");
+    return RevisionUtils.extract("$Revision: 10029 $");
   }
 
   /**
